@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #pragma once
 
@@ -27,18 +27,17 @@ public:
     // Fetch requessts
     Q_SIGNAL void requestAddMessage(const Message &message);
     Q_SIGNAL void requestMessagesForNumber(const QString &phoneNumber);
-    Q_SIGNAL void requestLastId();
-    Q_SIGNAL void requestMarkMessageDelivered(const int id);
+    Q_SIGNAL void requestUpdateMessageDeliveryState(const QString &id, const MessageState state);
     Q_SIGNAL void requestMarkMessageRead(const int id);
     Q_SIGNAL void requestChats();
     Q_SIGNAL void requestUnreadMessagesForNumber(const QString &phoneNumber);
     Q_SIGNAL void requestLastMessageForNumber(const QString &phoneNumber);
     Q_SIGNAL void requestLastContactedForNumber(const QString &phoneNumber);
     Q_SIGNAL void requestMarkChatAsRead(const QString &phoneNumber);
+    Q_SIGNAL void requestDeleteChat(const QString &phoneNumber);
 
     // Responses
     Q_SIGNAL void messagesFetchedForNumber(const QString &phoneNumber, const QVector<Message> messages);
-    Q_SIGNAL void lastIdFetched(const int id);
     Q_SIGNAL void chatsFetched(QVector<Chat> chats);
     Q_SIGNAL void unreadMessagesFetchedForNumber(const QString &phoneNumber, const int unreadMessages);
     Q_SIGNAL void lastMessageFetchedForNumber(const QString &phoneNumber, const QString &message);
@@ -47,14 +46,14 @@ public:
 private:
     Q_SLOT void addMessage(const Message &message);
     Q_SLOT void messagesForNumber(const QString &phoneNumber);
-    Q_SLOT void lastId();
-    Q_SLOT void markMessageDelivered(const int id);
+    Q_SLOT void updateMessageDeliveryState(const QString &id, const MessageState state);
     Q_SLOT void markMessageRead(const int id);
     Q_SLOT void chats();
     Q_SLOT void unreadMessagesForNumber(const QString &phoneNumber);
     Q_SLOT void lastMessageForNumber(const QString &phoneNumber);
     Q_SLOT void lastContactedForNumber(const QString &phoneNumber);
     Q_SLOT void markChatAsRead(const QString &phoneNumber);
+    Q_SLOT void deleteChat(const QString &phoneNumber);
 
     Database m_database;
 };
