@@ -27,14 +27,13 @@ ChatListModel::ChatListModel(ChannelHandler &handler, QObject *parent)
     , m_handler(handler)
     , m_mapper(ContactPhoneNumberMapper::instance())
 {
-    m_mapper.performInitialScan();
     connect(&m_handler.database(), &AsyncDatabase::messagesChanged, this, &ChatListModel::fetchChats);
     connect(&m_mapper, &ContactPhoneNumberMapper::contactsChanged, this, [this](const QVector<QString> &affectedNumbers) {
         qDebug() << "New data for" << affectedNumbers;
         for (const auto &number : affectedNumbers) {
             // Find the Chat object for the phone number
             const auto chatIt = std::find_if(m_chats.begin(), m_chats.end(), [&number](const Chat &chat) {
-                return PhoneNumberUtils::normalize(chat.phoneNumber) == number;
+                return phoneNumberUtils::normalizeNumber(chat.phoneNumber) == number;
             });
 
             int i = std::distance(m_chats.begin(), chatIt);
@@ -63,6 +62,7 @@ QHash<int, QByteArray> ChatListModel::roleNames() const
     return {
         {Role::DisplayNameRole, BL("displayName")},
         {Role::PhoneNumberRole, BL("phoneNumber")},
+        {Role::DisplayPhoneNumberRole, BL("displayPhoneNumber")},
         {Role::LastContactedRole, BL("lastContacted")},
         {Role::UnreadMessagesRole, BL("unreadMessages")},
         {Role::PhotoRole, BL("photo")},
@@ -82,8 +82,10 @@ QVariant ChatListModel::data(const QModelIndex &index, int role) const
         return KPeople::PersonData(m_mapper.uriForNumber(m_chats.at(index.row()).phoneNumber)).name();
     case PhotoRole:
         return KPeople::PersonData(m_mapper.uriForNumber(m_chats.at(index.row()).phoneNumber)).photo();
+    case DisplayPhoneNumberRole:
+        return phoneNumberUtils::normalizeNumber(m_chats.at(index.row()).phoneNumber, phoneNumberUtils::National);
     case PhoneNumberRole:
-        return PhoneNumberUtils::normalize(m_chats.at(index.row()).phoneNumber);
+        return phoneNumberUtils::normalizeNumber(m_chats.at(index.row()).phoneNumber);
     case LastContactedRole:
         return m_chats.at(index.row()).lastContacted;
     case UnreadMessagesRole:
