@@ -14,6 +14,7 @@
 // Models
 #include "chatlistmodel.h"
 #include "messagemodel.h"
+#include "contactmodel.h"
 
 #include <contactphonenumbermapper.h>
 #include "version.h"
@@ -40,6 +41,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     parser.addHelpOption();
     parser.setApplicationDescription(i18n("Spacebar SMS client"));
     parser.addPositionalArgument(QStringLiteral("number"), i18n("Open a chat with the given phone number"));
+    const auto modemOpt = QCommandLineOption(SL("modem"), SL("Modem path to use, for development purpose"), SL("modem"));
+    parser.addOption(modemOpt);
     parser.process(app);
 
     KLocalizedString::setApplicationDomain("spacebar");
@@ -49,7 +52,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     // Use using the instance getter
     new Utils(&engine);
 
-    ChannelHandler handler;
+    auto modemPath = parser.isSet(modemOpt) && !parser.value(modemOpt).isEmpty()
+            ? parser.value(modemOpt)
+            : std::optional<QString>();
+    ChannelHandler handler(modemPath);
     ChatListModel chatListModel(handler);
 
     // Register types
@@ -58,6 +64,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qRegisterMetaType<KPeople::PersonData *>("PersonData*");
     qmlRegisterAnonymousType<QAbstractItemModel>(APPLICATION_ID, 1);
     qmlRegisterSingletonInstance<Utils>(APPLICATION_ID, 1, 0, "Utils", Utils::instance());
+    qmlRegisterType<ContactModel>(APPLICATION_ID, 1, 0, "ContactModel");
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.addImageProvider(SL("avatar"), new AvatarImageProvider());
     engine.load(QUrl(SL("qrc:///main.qml")));
